Model Comparison Table

# Model Comparison

Below is a table comparing different model variants and their configurations.

Size | Patch Size | Resolution | Framework A | Framework B
--- | --- | --- | --- | ---
Base (86M) | 32 | 256 | org/model-base-patch32-256 | org/model-base-patch32-256-b
Base (86M) | 16 | 256 | org/model-base-patch16-256 | org/model-base-patch16-256-b
Base (86M) | 16 | 512 | org/model-base-patch16-512 | org/model-base-patch16-512-b
Large (400M) | 16 | 256 | org/model-large-patch16-256 | org/model-large-patch16-256-b
Large (400M) | 16 | 384 | org/model-large-patch16-384 | org/model-large-patch16-384-b
SO400M (400M) | 16 | 256 | org/model-so400m-patch16-256 | org/model-so400m-patch16-256-b
SO400M (400M) | 14 | 384 | org/model-so400m-patch14-384 | org/model-so400m-patch14-384-b
SO400M (400M) | 14 | 768 | org/model-so400m-patch14-768 | org/model-so400m-patch14-768-b

Each model variant is optimized for different use cases depending on resolution and patch size.